@@ -817,6 +817,28 @@ class DatabaseManager:
             if tb is not None:
                 tb.gen_test_reset()
 
+    def purge_test_data(self):
+        '''
+            Delete test data for all tables.
+
+            This is useful for using a data generator, it will purge all of the old data for a fresh start.
+
+            ----------
+
+            Meta
+            ----------
+            `author`: Colemen Atwood
+            `created`: 06-07-2022 16:42:52
+            `memberOf`: DatabaseManager
+            `version`: 1.0
+            `method_name`: purge_test_data
+            * @xxx [06-07-2022 16:43:59]: documentation for purge_test_data
+        '''
+
+
+        tb:_table_manager.TableManager
+        for tb in self.data['tables_instances']:
+            tb.delete_test_data()
 
     # def delete_table(self,table_names:_Union[list,str]):
     #     table_names = _lu.force_list(table_names)
@@ -1458,26 +1480,29 @@ class DatabaseManager:
             self.con.commit()
             success = True
 
+
+        except mysql.connector.errors.IntegrityError:
+            _log(f"{_traceback.format_exc()}","error")
+            _log(f"SQL: {sql}","error")
+
         except mysql.connector.errors.DatabaseError:
             # print(f"ERROR: {err}", PRESET="FATAL_ERROR_INVERT")
-            print(f"{_traceback.format_exc()}")
-            print(f"SQL: {sql}")
+            _log(f"{_traceback.format_exc()}","error")
+            _log(f"SQL: {sql}","error")
+
 
         except sqlite3.Warning as error:
-            print(f"Warning: {error}")
-            print(_traceback.format_exc())
+            _log(f"Warning: {error}","error")
+            _log(_traceback.format_exc(),"error")
 
         except sqlite3.OperationalError as error:
-            print(f"Fatal Error: {error}")
-            print(_traceback.format_exc())
+            _log(f"Fatal Error: {error}","error")
+            _log(_traceback.format_exc(),"error")
 
         except AttributeError:
-            print(f"{_traceback.format_exc()}")
-            print("")
-            print(f"{print(sys.exc_info()[2])}")
-            print("")
-            print("")
-            print(f"SQL: \033[38;2;(235);(64);(52)m{sql}")
+            _log(f"{_traceback.format_exc()}\n","error")
+            _log(f"{print(sys.exc_info()[2])}\n\n","error")
+            _log(f"SQL: \033[38;2;(235);(64);(52)m{sql}")
         return success
 
     def run_from_list(self, query_list,**kwargs):
@@ -1521,6 +1546,8 @@ class DatabaseManager:
         success = True
         for que in query_list:
             success = self.run(que)
+            if success is False:
+                break
 
         if disable_foreign_key_restraints is True:
             self.run("SET foreign_key_checks = 1;")
