@@ -203,9 +203,11 @@ class TableDataManager:
         if isinstance(sql,(str)):
             self.db.connect()
             # @Mstep [] execute the create table sql which will essentially truncate it and add new columns.
-            success = self.db.execute_sql_from_file(self.create_sql_path)
-            # @Mstep [] execute the insert sql
-            success = self.db.execute_sql_from_file(self.insert_path)
+            if _cfu.exists(self.create_sql_path):
+                success = self.db.execute_sql_from_file(self.create_sql_path)
+            if _cfu.exists(self.insert_path):
+                # @Mstep [] execute the insert sql
+                success = self.db.execute_sql_from_file(self.insert_path)
             # print(f"boobs")
         return success
 
@@ -267,6 +269,7 @@ class TableDataManager:
             * @xxx [06-05-2022 16:46:22]: documentation for delete_data
         '''
 
+        self.set_insert_data(None)
         success = False
         res = self.delete_sql_insert()
         if res is True:
@@ -359,7 +362,8 @@ class TableDataManager:
             -------------------------
             `data` {list|dict|None}
                 The insert data.
-                `!!! CAUTION !!!`
+
+                `!!! CAUTION !!!`\n
                 If data is None, the insert data is reset to an empty list.
 
                 If a list of dictionaries is provided, the dictionaries are appended as rows to the insert data.
