@@ -138,7 +138,37 @@ def force_list(value)->list:
         return [value]
     return value
 
+def count(subj:list,value:any)->int:
+    '''
+        Count how many times a value occurs in a list.
+        This is case sensitive, it will only count exact matches.
 
+        ----------
+
+        Arguments
+        -------------------------
+        `subj` {list}
+            The list to search.
+
+        `value` {any}
+            The value to search for.
+
+        Return {int}
+        ----------------------
+        The number of times the value occurs in the list.
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 06-07-2022 15:43:26
+        `memberOf`: list_utils
+        `version`: 1.0
+        `method_name`: count
+        * @xxx [06-07-2022 15:44:46]: documentation for count
+    '''
+
+
+    return len([x for x in subj if x == value])
 
 
 
